@@ -6,7 +6,7 @@ use crate::config;
 use crossterm::event::KeyEvent;
 
 use crate::handlers::{self, KeyHandler};
-use crate::painters::*;
+use crate::painters::{draw_post, draw_settings, draw_test_and_update, Painter};
 use crate::settings::Settings;
 use crate::typer::TestState;
 use crate::Term;
@@ -109,14 +109,15 @@ impl<'t> Default for App<'t> {
     /// the test isnt initialized though
     fn default() -> Self {
         Self {
-            test: TestState::default(),
             is_alive: true,
             margin: 2,
             paragraph: 62,
-            settings: Settings::default(),
-            /// unwrap wont painc because the Squad Default always returns Some
+
             painter: draw_test_and_update,
             key_handler: handlers::typer::handle,
+
+            settings: Settings::default(),
+            test: TestState::default(),
         }
     }
 }
